@@ -193,6 +193,7 @@ METHOD(jsonSerialize)
 {
     PARSE_NONE;
     ds_map_to_array(THIS_DS_MAP(), return_value);
+    convert_to_object(return_value);
 }
 
 METHOD(filter)
@@ -280,6 +281,35 @@ METHOD(xor)
     RETURN_DS_MAP(ds_map_xor(THIS_DS_MAP(), Z_DS_MAP_P(obj)));
 }
 
+METHOD(getIterator) {
+    PARSE_NONE;
+    ZVAL_COPY(return_value, getThis());
+}
+
+METHOD(offsetExists)
+{
+    PARSE_ZVAL(offset);
+    RETURN_BOOL(ds_htable_isset(THIS_DS_MAP()->table, offset, false));
+}
+
+METHOD(offsetGet)
+{
+    PARSE_ZVAL(offset);
+    RETURN_ZVAL_COPY(ds_map_get(THIS_DS_MAP(), offset, NULL));
+}
+
+METHOD(offsetSet)
+{
+    PARSE_ZVAL_ZVAL(offset, value);
+    ds_map_put(THIS_DS_MAP(), offset, value);
+}
+
+METHOD(offsetUnset)
+{
+    PARSE_ZVAL(offset);
+    ds_map_remove(THIS_DS_MAP(), offset, NULL, return_value);
+}
+
 void php_ds_register_map()
 {
     zend_class_entry ce;
@@ -317,6 +347,12 @@ void php_ds_register_map()
         PHP_DS_ME(Map, union)
         PHP_DS_ME(Map, values)
         PHP_DS_ME(Map, xor)
+        PHP_DS_ME(Map, getIterator)
+
+        PHP_DS_ME(Map, offsetExists)
+        PHP_DS_ME(Map, offsetGet) 
+        PHP_DS_ME(Map, offsetSet) 
+        PHP_DS_ME(Map, offsetUnset)
 
         PHP_DS_COLLECTION_ME_LIST(Map)
         PHP_FE_END
@@ -336,7 +372,11 @@ void php_ds_register_map()
         STR_AND_LEN("MIN_CAPACITY"),
         DS_HTABLE_MIN_CAPACITY
     );
+    
+    zend_class_implements(php_ds_map_ce, 2, 
+        collection_ce, 
+        zend_ce_arrayaccess
+    );
 
-    zend_class_implements(php_ds_map_ce, 1, collection_ce);
     php_ds_register_map_handlers();
 }
