@@ -7,7 +7,8 @@
 typedef struct _php_ds_stack_iterator_t {
     zend_object_iterator     intern;
     zend_long                position;
-    php_ds_stack_t          *stack;
+    zend_object             *object;
+    ds_stack_t              *stack;
 } php_ds_stack_iterator_t;
 
 zend_object_iterator *php_ds_stack_get_iterator(zend_class_entry *ce, zval *object, int by_ref);
