@@ -3,7 +3,16 @@
 
 #include "../../ds/ds_stack.h"
 
-#define Z_DS_STACK(z)   (((php_ds_stack_t*)(Z_OBJ(z)))->stack)
+typedef struct _php_ds_stack_t {
+    ds_stack_t      *stack;
+    zend_object      std;
+} php_ds_stack_t;
+
+static inline php_ds_stack_t *php_ds_stack_fetch_object(zend_object *obj) {
+	return (php_ds_stack_t *)((char*)(obj) - XtOffsetOf(php_ds_stack_t, std));
+}
+
+#define Z_DS_STACK(z)   php_ds_stack_fetch_object(Z_OBJ(z))->stack
 #define Z_DS_STACK_P(z) Z_DS_STACK(*z)
 #define THIS_DS_STACK() Z_DS_STACK_P(getThis())
 
@@ -20,11 +29,6 @@ do {                                        \
     return;                                 \
 } while(0)
 
-typedef struct _php_ds_stack_t {
-    zend_object      std;
-    ds_stack_t      *stack;
-} php_ds_stack_t;
-
 zend_object *php_ds_stack_create_object_ex(ds_stack_t *stack);
 zend_object *php_ds_stack_create_object(zend_class_entry *ce);
 zend_object *php_ds_stack_create_clone(ds_stack_t *stack);
